@@ -105,7 +105,7 @@ class Resource:
         kwargs.pop('emitter_format', None)
         
         # Execute request
-        try:          
+        try:      
             # Dictionary containing {'data': <Serialized result>}                
             response_dictionary = self.handler.execute_request(request, *args, **kwargs)
         except Exception, e:        
@@ -403,13 +403,13 @@ class Resource:
         subject = 'django-icetea crash report'
         html = reporter.get_traceback_html()
         message = EmailMessage(
-            settings.EMAIL_SUBJECT_PREFIX + subject,
-            html,
-            settings.SERVER_EMAIL,
-            [admin[1] for admin in settings.ADMINS]
+            subject=settings.EMAIL_SUBJECT_PREFIX + subject,
+            body=html,
+            from_email=settings.SERVER_EMAIL,
+            to=[admin[1] for admin in settings.ADMINS],
         )
         message.content_subtype = 'html'
-        message.send(fail_silently=False)
+        message.send(fail_silently=True)
 
     def response_add_debug(self, response_dictionary):
         """
